@@ -6,9 +6,10 @@ module VagrantPlugins
 
           case machine.guest.capability("flavor")
             when :centos_8
-              # No need to install epel. fuse-sshfs comes from the PowerTools repo
+              # No need to install epel. fuse-sshfs comes from the powertools repo
               # https://bugzilla.redhat.com/show_bug.cgi?id=1758884
-              machine.communicate.sudo("yum -y install --enablerepo=PowerTools fuse-sshfs")
+              # https://github.com/dustymabe/vagrant-sshfs/issues/123
+              machine.communicate.sudo("yum -y install --enablerepo=powertools fuse-sshfs")
             when :centos_7, :centos # centos7 and centos6
               # Install fuse-sshfs from epel
               if !epel_installed(machine)
